==> kmymoney_5.1.3.orig.tar.xz: kmymoney-5.1.3/kmymoney/plugins/woob/woob.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "romain@symlink.me",
                "Name": "Romain Bignon",
                "Name[ca@valencia]": "Romain Bignon",
                "Name[ca]": "Romain Bignon",
                "Name[cs]": "Romain Bignon",
                "Name[de]": "Romain Bignon",
                "Name[en_GB]": "Romain Bignon",
                "Name[es]": "Romain Bignon",
                "Name[et]": "Romain Bignon",
                "Name[eu]": "Romain Bignon",
                "Name[fi]": "Romain Bignon",
                "Name[fr]": "Romain Bignon",
                "Name[gl]": "Romain Bignon",
                "Name[ia]": "Romain Bignon",
                "Name[it]": "Romain Bignon",
                "Name[ko]": "Romain Bignon",
                "Name[nl]": "Romain Bignon",
                "Name[pl]": "Romain Bignon",
                "Name[pt]": "Romain Bignon",
                "Name[pt_BR]": "Romain Bignon",
                "Name[ru]": "Romain Bignon",
                "Name[sk]": "Romain Bignon",
                "Name[sl]": "Romain Bignon",
                "Name[sv]": "Romain Bignon",
                "Name[uk]": "Romain Bignon",
                "Name[x-test]": "xxRomain Bignonxx",
                "Name[zh_CN]": "Romain Bignon"
            }
        ],
        "Description": "Plugin for Woob",
        "Description[ca@valencia]": "Connector per al Woob",
        "Description[ca]": "Connector per al Woob",
        "Description[cs]": "Modul Woob",
        "Description[en_GB]": "Plugin for Woob",
        "Description[es]": "Complemento para Woob",
        "Description[fr]": "Module externe pour Woob",
        "Description[ia]": "Plugin per Woob",
        "Description[it]": "Estensione per Woob",
        "Description[ko]": "Woob용 플러그인",
        "Description[nl]": "Plug-in voor Woob",
        "Description[pl]": "Wtyczka dla Woob",
        "Description[pt_BR]": "Plugin para Woob",
        "Description[sl]": "Vtičnik za Woob",
        "Description[sv]": "Insticksprogram för Woob",
        "Description[uk]": "Додаток для Woob",
        "Description[x-test]": "xxPlugin for Woobxx",
        "Description[zh_CN]": "Woob 插件",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "woob",
        "License": "GPL",
        "Name": "Woob",
        "Name[ca@valencia]": "Woob",
        "Name[ca]": "Woob",
        "Name[cs]": "Woob",
        "Name[en_GB]": "Woob",
        "Name[es]": "Woob",
        "Name[fr]": "Woob",
        "Name[ia]": "Woob",
        "Name[it]": "Woob",
        "Name[ko]": "Woob",
        "Name[nl]": "Woob",
        "Name[pl]": "Woob",
        "Name[pt_BR]": "Woob",
        "Name[sl]": "Woob",
        "Name[sv]": "Woob",
        "Name[uk]": "Woob",
        "Name[x-test]": "xxWoobxx",
        "Name[zh_CN]": "Woob",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney-5.1.92.tar.xz: kmymoney-5.1.92/kmymoney/plugins/woob/woob.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "romain@symlink.me",
                "Name": "Romain Bignon",
                "Name[ca@valencia]": "Romain Bignon",
                "Name[ca]": "Romain Bignon",
                "Name[cs]": "Romain Bignon",
                "Name[de]": "Romain Bignon",
                "Name[en_GB]": "Romain Bignon",
                "Name[eo]": "Romain Bignon",
                "Name[es]": "Romain Bignon",
                "Name[et]": "Romain Bignon",
                "Name[eu]": "Romain Bignon",
                "Name[fi]": "Romain Bignon",
                "Name[fr]": "Romain Bignon",
                "Name[gl]": "Romain Bignon",
                "Name[ia]": "Romain Bignon",
                "Name[it]": "Romain Bignon",
                "Name[ka]": "Romain Bignon",
                "Name[ko]": "Romain Bignon",
                "Name[nb]": "Romain Bignon",
                "Name[nl]": "Romain Bignon",
                "Name[pl]": "Romain Bignon",
                "Name[pt]": "Romain Bignon",
                "Name[pt_BR]": "Romain Bignon",
                "Name[ru]": "Romain Bignon",
                "Name[sk]": "Romain Bignon",
                "Name[sl]": "Romain Bignon",
                "Name[sv]": "Romain Bignon",
                "Name[tr]": "Romain Bignon",
                "Name[uk]": "Romain Bignon",
                "Name[x-test]": "xxRomain Bignonxx",
                "Name[zh_CN]": "Romain Bignon",
                "Name[zh_TW]": "Romain Bignon"
            }
        ],
        "Description": "Plugin for Woob",
        "Description[ca@valencia]": "Connector per a Woob",
        "Description[ca]": "Connector per al Woob",
        "Description[cs]": "Modul Woob",
        "Description[en_GB]": "Plugin for Woob",
        "Description[eo]": "Kromaĵo por Woob",
        "Description[es]": "Complemento para Woob",
        "Description[eu]": "Woob plugina",
        "Description[fi]": "Woob-liitännäinen",
        "Description[fr]": "Module externe pour Woob",
        "Description[gl]": "Complemento para Woob.",
        "Description[it]": "Estensione per Woob",
        "Description[ka]": "Woob-ის დამატება",
        "Description[ko]": "Woob용 플러그인",
        "Description[nb]": "Programtillegg for Woob",
        "Description[nl]": "Plug-in voor Woob",
        "Description[pl]": "Wtyczka dla Woob",
        "Description[pt]": "'Plugin' do Woob",
        "Description[pt_BR]": "Plugin para Woob",
        "Description[ru]": "Модуль для Woob",
        "Description[sl]": "Vtičnik za Woob",
        "Description[sv]": "Insticksprogram för Woob",
        "Description[tr]": "Woob için eklenti",
        "Description[uk]": "Додаток для Woob",
        "Description[x-test]": "xxPlugin for Woobxx",
        "Description[zh_CN]": "Woob 插件",
        "Description[zh_TW]": "Woob 外掛程式",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "woob",
        "License": "GPL",
        "Name": "Woob",
        "Name[ca@valencia]": "Woob",
        "Name[ca]": "Woob",
        "Name[cs]": "Woob",
        "Name[en_GB]": "Woob",
        "Name[eo]": "Woob",
        "Name[es]": "Woob",
        "Name[eu]": "Woob",
        "Name[fi]": "Woob",
        "Name[fr]": "Woob",
        "Name[gl]": "Woob",
        "Name[it]": "Woob",
        "Name[ka]": "Woob",
        "Name[ko]": "Woob",
        "Name[nb]": "Woob",
        "Name[nl]": "Woob",
        "Name[pl]": "Woob",
        "Name[pt]": "Woob",
        "Name[pt_BR]": "Woob",
        "Name[ru]": "Woob",
        "Name[sl]": "Woob",
        "Name[sv]": "Woob",
        "Name[tr]": "Woob",
        "Name[uk]": "Woob",
        "Name[x-test]": "xxWoobxx",
        "Name[zh_CN]": "Woob",
        "Name[zh_TW]": "Woob",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
